==> 1.0.43+1.tar.gz: lib/components/UikProductPageInformationContainer.dart <==
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikTextProps.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

import '../props/UikProductPageInformationContainerProps.dart';

class UikProductPageInformationContainer extends UikWidget {
  WidgetType _widgetType;
  UikProductPageInformationContainerProps
      _uikProductPageInformationContainerProps;
  UikProductPageInformationContainer(
      this._widgetType, this._uikProductPageInformationContainerProps)
      : super(_widgetType, _uikProductPageInformationContainerProps);

  @override
  _UikProductPageInformationContainerState createState() =>
      _UikProductPageInformationContainerState(
          _uikProductPageInformationContainerProps);
}

class _UikProductPageInformationContainerState
    extends State<UikProductPageInformationContainer> {
  UikProductPageInformationContainerProps
      _uikProductPageInformationContainerProps;
  _UikProductPageInformationContainerState(
      this._uikProductPageInformationContainerProps);

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(left: 16, top: 36, right: 23),
      child: Column(
        children: [
          Container(
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Container(
                  child: Text(
                    "Product information",
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                ),
                Container(
                  child: Icon(Icons.arrow_back_rounded),
                )
              ],
            ),
          ),
          Container(
            margin: const EdgeInsets.only(
              top: 40,
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Container(
                  child: Text(
                    "Reviews",
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                ),
                Container(
                  child: Text(
                    _uikProductPageInformationContainerProps.reviews.toString(),
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                )
              ],
            ),
          ),
          Container(
            margin: const EdgeInsets.only(top: 40, bottom: 40),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Container(
                  child: Text(
                    "Questions and answers",
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                ),
                Container(
                  child: Text(
                    _uikProductPageInformationContainerProps.questionsAndAnswers
                        .toString(),
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> 1.0.90+1.tar.gz: lib/components/UikProductPageInformationContainer.dart <==
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikTextProps.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

import '../props/UikProductPageInformationContainerProps.dart';

class UikProductPageInformationContainer extends UikWidget {
  WidgetType _widgetType;
  UikProductPageInformationContainerProps
      _uikProductPageInformationContainerProps;
  UikProductPageInformationContainer(
      this._widgetType, this._uikProductPageInformationContainerProps)
      : super(_widgetType, _uikProductPageInformationContainerProps);

  @override
  _UikProductPageInformationContainerState createState() =>
      _UikProductPageInformationContainerState(
          _uikProductPageInformationContainerProps);
}

class _UikProductPageInformationContainerState
    extends State<UikProductPageInformationContainer> {
  UikProductPageInformationContainerProps
      _uikProductPageInformationContainerProps;
  _UikProductPageInformationContainerState(
      this._uikProductPageInformationContainerProps);

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(left: 16, top: 36, right: 23),
      child: Column(
        children: [
          Container(
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Container(
                  child: const Text(
                    "Product information",
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                    ),
                  ),
                ),
                Container(
                  child: const Icon(Icons.arrow_forward_ios_rounded , size: 22,),
                )
              ],
            ),
          ),
          Container(
            margin: const EdgeInsets.only(
              top: 40,
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Container(
                  child: const Text(
                    "Reviews",
                    style: TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                      fontFamily: 'poppins', 
                    ),
                  ),
                ),
                Container(
                  child: Text(
                    _uikProductPageInformationContainerProps.reviews.toString(),
                    style: const TextStyle(
                      fontSize: 16,
                      fontWeight: FontWeight.w400,
                      fontFamily: 'poppins', 
                    ),
                  ),
                )
              ],
            ),
          ),
          // Container(
          //   margin: const EdgeInsets.only(top: 40, bottom: 40),
          //   child: Row(
          //     mainAxisAlignment: MainAxisAlignment.spaceBetween,
          //     children: [
                // Container(
                //   child: Text(
                //     "Questions and answers",
                //     style: TextStyle(
                //       fontSize: 16,
                //       fontWeight: FontWeight.w400,
                //     ),
                //   ),
                // ),
                // Container(
                //   child: Text(
                //     _uikProductPageInformationContainerProps.questionsAndAnswers
                //         .toString(),
                //     style: TextStyle(
                //       fontSize: 16,
                //       fontWeight: FontWeight.w400,
                //     ),
                //   ),
                // )
          //     ],
          //   ),
          // ),
        ],
      ),
    );
  }
}
